CsMoneroFlutterLibsAndroidArm64V8aPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CsMoneroFlutterLibsAndroidArm64V8aPlatform
Implementers

Constructors

CsMoneroFlutterLibsAndroidArm64V8aPlatform()
Constructs a CsMoneroFlutterLibsAndroidArm64V8aPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CsMoneroFlutterLibsAndroidArm64V8aPlatform
The default instance of CsMoneroFlutterLibsAndroidArm64V8aPlatform to use.
getter/setter pair